@@ -123,6 +123,22 @@ class DiffConvert:
       changed in the configuration, so only a 'new' argument is
       supplied; calls update(new, None, new, *args) by default.
 
+    In addition, there are some filter methods which are called with the
+    same wildcard arguments as the conversion action methods, above.  If
+    this returns a false value, this particular conversion will be
+    skipped:
+
+    * filter_delete() - called before a delete(), remove() or
+      truncate().
+
+    * filter_update() - called before an add() or update().
+
+    * filter_trigger() - called before a trigger().
+
+    * filter() - by default, the above method calls the same filter()
+      method allowing all conversion actions to be filtered in one
+      place.
+
     In most cases, only the remove() and update() methods need defining
     as the add() and trigger() methods call update(), and truncate() is
     rarely required, but there some odd cases where they are, hence
@@ -215,10 +231,12 @@ class DiffConvert:
             i for i, v in enumerate(self._path_full)
                 if (v is None) or isinstance(v, set) ]
 
-        # set _context_args value for this converter, which is used by
-        # the split_args() method to vary the split between the
-        # arguments used in the context vs those in the cmd and ext
-        # elements returned by that function
+        # set _context_args value for this converter, specifies the
+        # number of wildcard arguments in the context (vs the cmd/ext),
+        # and used by split_args() method
+        #
+        # by default, this counts the number of wildcard arguments in
+        # the context but can be adjusted with split_args_offset
         #
         # this is useful when writing converters which can work in
         # several different contexts (such as those for commands in BGP
@@ -228,7 +246,8 @@ class DiffConvert:
         # the context will be included in the cmd/ext side; positive
         # values will shift the other way
         self._context_args = (
-            len([ i for i, v in enumerate(self.context) if v is None ])
+            len([ i for i, v in enumerate(self.context)
+                     if (v is None) or isinstance(v, set) ])
             + self.split_args_offset)
 
 
@@ -416,6 +435,16 @@ class DiffConvert:
         return self.context + self.cmd
 
 
+    def get_sorting_key(self):
+        """This method returns the key to be used for ordering the
+        converters.  By default, this returns the full path (which is
+        context + cmd + ext; see the constructor) but it can be modified
+        to adjust the order in which converters operate, within a block.
+        """
+
+        return self._path_full
+
+
     def get_match_context(self, match):
         """Return the context portion of a particular match for this
         converter.
@@ -490,6 +519,54 @@ class DiffConvert:
         return [ match[i] for i in self.wildcard_indices ]
 
 
+    def filter(self, *args):
+        """Specifies if a particular conversion is to be filtered out
+        (return = False) or executed (True), given the wildcard match
+        arguments.
+
+        This filtering could be done by the action methods delete(),
+        remove(), truncate(), add(), update() and trigger() but
+        sometimes it is useful to separate this out to operate
+        independently, if a filter method is to be shared across a set
+        of subclasses.
+
+        A side benefit is it's also a bit quicker as the filtering
+        happens before all the differences are calculated.
+
+        This method is not called directly by convert() but provides a
+        single method that the individual action filtering methods
+        (filter_delete(), filter_update() and filter_trigger()) will
+        call by default, if all types of action are to be equially
+        filtered.
+        """
+
+        return True
+
+
+    def filter_delete(self, *args):
+        """See filter() - this method is called by convert() before a
+        delete()/remove()/truncate() action is called.
+        """
+
+        return self.filter(*args)
+
+
+    def filter_update(self, *args):
+        """See filter() - this method is called by convert() before an
+        add()/update() action is called.
+        """
+
+        return self.filter(*args)
+
+
+    def filter_trigger(self, *args):
+        """See filter() - this method is called by convert() before a
+        trigger() action is called.
+        """
+
+        return self.filter(*args)
+
+
     def delete(self, old, rem, new, *args):
         """The delete() method is called when the specified path is in
         the remove differences (i.e. it's in the old configuration but
@@ -802,11 +879,13 @@ class DiffConfig:
         will be raised.
         """
 
-        if cvt.block not in self._cvts:
-            raise KeyError("block: %s not found for converter: %s"
-                                % (cvt.block, type(cvt).__name__))
+        block = cvt.block
 
-        self._cvts[cvt.block].append(cvt)
+        if block not in self._cvts:
+            raise KeyError("converter: %s block: %s not found"
+                                % (type(cvt).__name__, block))
+
+        self._cvts[block].append(cvt)
 
 
     def _sort_converters(self):
@@ -819,7 +898,7 @@ class DiffConfig:
         """
 
         for block in self._cvts:
-            self._cvts[block].sort(key=lambda c: c._path_full)
+            self._cvts[block].sort(key=lambda c: c.get_sorting_key())
 
 
     def _explain_comment(self, path):
@@ -1036,6 +1115,21 @@ class DiffConfig:
                 deepremoveitems(d, path_dict)
 
 
+    def update_dump_config(self, new_dump_config):
+        "Updates the dump configuration setting."
+        self._dump_config = new_dump_config
+
+
+    def update_dump_diff(self, new_dump_diff):
+        "Updates the dump differences setting."
+        self._dump_diff = new_dump_diff
+
+
+    def update_debug_convert(self, new_debug_convert):
+        "Updates the debug conversion level."
+        self._debug_convert = new_debug_convert
+
+
     def _print_debug(self, msg, blank_if_single=True):
         """Print the supplied debugging message followed by a blank
         line, if it's not empty (in which case, do nothing), unless
@@ -1051,10 +1145,10 @@ class DiffConfig:
             self._print_debug_converter()
 
             for line in msg:
-                print(line)
+                print(line, file=sys.stderr)
 
             if blank_if_single or (len(msg) > 1):
-                print()
+                print(file=sys.stderr)
 
 
     def _print_debug_block(self):
@@ -1070,10 +1164,8 @@ class DiffConfig:
             """
 
             if self._debug_block_msg:
-                for line in self._debug_block_msg:
-                    print(line)
-
-                print()
+                for line in self._debug_block_msg + [""]:
+                    print(line, file=sys.stderr)
 
                 self._debug_block_msg = []
 
@@ -1091,10 +1183,8 @@ class DiffConfig:
             """
 
             if self._debug_converter_msg:
-                for line in self._debug_converter_msg:
-                    print(line)
-
-                print()
+                for line in self._debug_converter_msg + [""]:
+                    print(line, file=sys.stderr)
 
                 self._debug_converter_msg = []
 
@@ -1299,6 +1389,32 @@ class DiffConfig:
                                 + pathstr(match, cvt.wildcard_indices))
 
 
+                    # get elements in the path matching wildcards
+
+                    args = cvt.get_wildcard_args(match)
+
+
+                    # skip this conversion if it is filtered out
+
+                    try:
+                        filtered = cvt.filter_delete(*args)
+
+                    except:
+                        print("Exception in %s.filter_delete() with:"
+                                  % type(cvt),
+                              "  *args=" + repr(args),
+                              "",
+                              sep="\n", file=sys.stderr)
+
+                        raise
+
+                    if not filtered:
+                        if self._debug_convert >= DEBUG_CONVERT_NODIFF:
+                            debug_msg.append("-> filtered - skip")
+                            self._print_debug(debug_msg)
+                        continue
+
+
                     # if we're removing the entire context for this
                     # match, we don't need to do it, as that will
                     # remove this, while it's at it
@@ -1364,11 +1480,6 @@ class DiffConfig:
                             yaml.dump(cvt_new, default_flow_style=False)])
 
 
-                    # get elements in the path matching wildcards
-
-                    args = cvt.get_wildcard_args(match)
-
-
                     # call the delete converter action method using the
                     # corresponding entry from the old configuration
 
@@ -1395,10 +1506,9 @@ class DiffConfig:
                                          else "delete"),
                               *action_args_str,
                               "  *args=" + repr(args),
+                              "",
                               sep="\n", file=sys.stderr)
 
-                        print()
-
                         raise
 
 
@@ -1493,8 +1603,28 @@ class DiffConfig:
                                 + pathstr(match, cvt.wildcard_indices))
 
 
+                    # (same as in remove, above)
+
                     args = cvt.get_wildcard_args(match)
 
+                    try:
+                        filtered = cvt.filter_update(*args)
+
+                    except:
+                        print("Exception in %s.filter_update() with:"
+                                  % type(cvt),
+                              "  *args=" + repr(args),
+                              "",
+                              sep="\n", file=sys.stderr)
+
+                        raise
+
+                    if not filtered:
+                        if self._debug_convert >= DEBUG_CONVERT_NODIFF:
+                            debug_msg.append("-> filtered - skip")
+                            self._print_debug(debug_msg)
+                        continue
+
 
                     # check if there is anything for this level in the
                     # old configuration - if not, we're actually adding
@@ -1559,10 +1689,9 @@ class DiffConfig:
                                      "add" if update_is_add else "update"),
                               *action_args_str,
                               "  *args=" + repr(args),
+                              "",
                               sep="\n", file=sys.stderr)
 
-                        print()
-
                         raise
 
 
@@ -1634,8 +1763,28 @@ class DiffConfig:
                                    pathstr(match, cvt.wildcard_indices)))
 
 
+                    # (same as in remove, above)
+
                     args = cvt.get_wildcard_args(match)
 
+                    try:
+                        filtered = cvt.filter_trigger(*args)
+
+                    except:
+                        print("Exception in %s.filter_trigger() with:"
+                                  % type(cvt),
+                              "  *args=" + repr(args),
+                              "",
+                              sep="\n", file=sys.stderr)
+
+                        raise
+
+                    if not filtered:
+                        if self._debug_convert >= DEBUG_CONVERT_NODIFF:
+                            debug_msg.append("-> filtered - skip")
+                            self._print_debug(debug_msg)
+                        continue
+
 
                     # get the old, update and new parts of the
                     # configuration difference dictionaries for the path
