@@ -45,7 +45,7 @@ def neighbor_canonicalize(nbr):
 
 class Cmd_IPRoute(IndentedContextualCommand):
     match = (r"ip route( vrf (?P<vrf>\S+))? (?P<base>\S+) (?P<netmask>\S+)"
-             r"( (?P<int_name>[-A-Za-z]+\d+))?( (?P<router>\S+))?"
+             r"( (?P<int_name>[-A-Za-z]+[0-9/.]+))?( (?P<router>[0-9.]+))?"
              r"( (?P<metric1>\d+))?( tag (?P<tag>\d+))?( (?P<metric2>\d+))?")
 
     def parse(self, cfg, vrf, base, netmask, int_name, router, metric1, tag,
@@ -63,7 +63,11 @@ class Cmd_IPRoute(IndentedContextualCommand):
         # comparing the identifiers
         id = (int_name or "-") + " " + (router or "-")
 
-        r = { "interface": int_name, "router": router }
+        r = {}
+        if int_name:
+            r["interface"] = int_name
+        if router:
+            r["router"] = router
         if metric1 or metric2:
             r["metric"] = int(metric1 or metric2)
         if tag:
@@ -74,7 +78,7 @@ class Cmd_IPRoute(IndentedContextualCommand):
 
 class Cmd_IPv6Route(IndentedContextualCommand):
     match = (r"ipv6 route( vrf (?P<vrf>\S+))? (?P<net>\S+)"
-             r"( (?P<int_name>[-A-Za-z]+\d+))?( (?P<router>\S+))?"
+             r"( (?P<int_name>[-A-Za-z]+[0-9/.]+))?( (?P<router>[0-9a-f:]+))?"
              r"( (?P<metric1>\d+))?( tag (?P<tag>\d+))?( (?P<metric2>\d+))?")
 
     def parse(self, cfg, vrf, net, int_name, router, metric1, tag, metric2):
@@ -84,13 +88,16 @@ class Cmd_IPv6Route(IndentedContextualCommand):
 
         id = (int_name or "-") + " " + (router or "-")
 
-        r = { "interface": int_name, "router": router }
+        r = {}
+        if int_name:
+            r["interface"] = int_name
+        if router:
+            r["router"] = router
         if metric1 or metric2:
             r["metric"] = int(metric1 or metric2)
         if tag:
             r["tag"] = int(tag)
 
-
         deepsetdefault(cfg, "ipv6-route", vrf, net)[id] = r
 
 
@@ -237,22 +244,6 @@ class Cmd_RtMap_SetIPv6NxtHop(CmdContext_RtMap):
             l.append({ "addr": addr })
 
 
-class Cmd_RtMap_SetIPv6NxtHopVrfyTrk(CmdContext_RtMap):
-    match = (r"set ipv6 next-hop verify-availability (?P<addr>[0-9a-f: ]+) "
-             r"(?P<seq>\d+) track (?P<obj>\d+)")
-
-    def parse(self, cfg, addr, seq, obj):
-        # the next-hop addresses are a list, built up in the order
-        # they're specified, optionally with a named or global VRF
-        # TODO: canonicalise address
-        v = deepsetdefault(
-                cfg, "set", "ipv6-next-hop-verify-availability-track")
-        v[int(seq)] = {
-            "addr": addr,
-            "track-obj": int(obj)
-        }
-
-
 class Cmd_RtMap_SetLocalPref(CmdContext_RtMap):
     match = r"set local-preference (?P<pref>\d+)"
 
