@@ -22,9 +22,11 @@ from ...misc import get_all_subclasses
 
 
 # the converters are all subclasses of DiffConvert which have the 'cmd'
-# attribute defined
+# attribute defined, stored as a set - the order is not important as we
+# sort the list later
 #
 # CiscoIOSDiffConfig._add_converters() adds these into the list of
 # converter classes
 
-converters = [ c for c in get_all_subclasses(DiffConvert) if c.cmd is not None ]
+converters = {
+    c for c in get_all_subclasses(DiffConvert) if c.cmd is not None  }
