@@ -160,7 +160,7 @@ class Cvt_RtMap_MatchIPAddr_Del(Cvt_RtMap_MatchIPAddr):
 
     def truncate(self, old, rem, new, rtmap, seq):
         l = self.enter(rtmap, old, seq)
-        for addr in self.get_ext(rem):
+        for addr in sorted(self.get_ext(rem)):
             l.append(" no match ip address " + addr)
         return l
 
@@ -169,7 +169,7 @@ class Cvt_RtMap_MatchIPAddr_Add(Cvt_RtMap_MatchIPAddr):
 
     def update(self, old, upd, new, rtmap, seq):
         l = self.enter(rtmap, new, seq)
-        for addr in self.get_ext(upd):
+        for addr in sorted(self.get_ext(upd)):
             l.append(" match ip address " + addr)
         return l
 
@@ -183,7 +183,7 @@ class Cvt_RtMap_MatchIPPfxLst_Del(Cvt_RtMap_MatchIPPfxLst):
 
     def truncate(self, old, rem, new, rtmap, seq):
         l = self.enter(rtmap, old, seq)
-        for pfx in self.get_ext(rem):
+        for pfx in sorted(self.get_ext(rem)):
             l.append(" no match ip address prefix-list " + pfx)
         return l
 
@@ -192,7 +192,7 @@ class Cvt_RtMap_MatchIPPfxLst_Add(Cvt_RtMap_MatchIPPfxLst):
 
     def update(self, old, upd, new, rtmap, seq):
         l = self.enter(rtmap, new, seq)
-        for pfx in self.get_ext(upd):
+        for pfx in sorted(self.get_ext(upd)):
             l.append(" match ip address prefix-list " + pfx)
         return l
 
@@ -206,7 +206,7 @@ class Cvt_RtMap_MatchIPv6Addr_Del(Cvt_RtMap_MatchIPv6Addr):
 
     def truncate(self, old, rem, new, rtmap, seq):
         l = self.enter(rtmap, old, seq)
-        for addr in self.get_ext(rem):
+        for addr in sorted(self.get_ext(rem)):
             l.append(" no match ipv6 address " + addr)
         return l
 
@@ -215,7 +215,7 @@ class Cvt_RtMap_MatchIPv6Addr_Add(Cvt_RtMap_MatchIPv6Addr):
 
     def update(self, old, upd, new, rtmap, seq):
         l = self.enter(rtmap, new, seq)
-        for addr in self.get_ext(upd):
+        for addr in sorted(self.get_ext(upd)):
             l.append(" match ipv6 address " + addr)
         return l
 
@@ -229,7 +229,7 @@ class Cvt_RtMap_MatchIPv6PfxLst_Del(Cvt_RtMap_MatchIPv6PfxLst):
 
     def truncate(self, old, rem, new, rtmap, seq):
         l = self.enter(rtmap, old, seq)
-        for pfx in self.get_ext(rem):
+        for pfx in sorted(self.get_ext(rem)):
             l.append(" no match ipv6 address prefix-list " + pfx)
         return l
 
@@ -238,7 +238,7 @@ class Cvt_RtMap_MatchIPv6PfxLst_Add(Cvt_RtMap_MatchIPv6PfxLst):
 
     def update(self, old, upd, new, rtmap, seq):
         l = self.enter(rtmap, new, seq)
-        for pfx in self.get_ext(upd):
+        for pfx in sorted(self.get_ext(upd)):
             l.append(" match ipv6 address prefix-list " + pfx)
         return l
 
@@ -252,7 +252,7 @@ class Cvt_RtMap_MatchTag_Del(Cvt_RtMap_MatchTag):
 
     def truncate(self, old, rem, new, rtmap, seq):
         l = self.enter(rtmap, old, seq)
-        for tag in self.get_ext(rem):
+        for tag in sorted(self.get_ext(rem)):
             l.append(" no match tag " + str(tag))
         return l
 
@@ -261,31 +261,36 @@ class Cvt_RtMap_MatchTag_Add(Cvt_RtMap_MatchTag):
 
     def update(self, old, upd, new, rtmap, seq):
         l = self.enter(rtmap, new, seq)
-        for tag in self.get_ext(upd):
+        for tag in sorted(self.get_ext(upd)):
             l.append(" match tag " + str(tag))
         return l
 
 
 class Cvt_RtMap_SetCmty(DiffConvert_RtMap_Entry):
     cmd = tuple()
-    ext = "set", "community"
+    ext = "set", "community", "communities"
 
 class Cvt_RtMap_SetCmty_Del(Cvt_RtMap_SetCmty):
     block = "rtmap-del"
 
     def truncate(self, old, rem, new, rtmap, seq):
         l = self.enter(rtmap, old, seq)
-        for cmty in self.get_ext(rem):
+        for cmty in sorted(self.get_ext(rem)):
             l.append(" no set community " + cmty)
         return l
 
 class Cvt_RtMap_SetCmty_Add(Cvt_RtMap_SetCmty):
     block = "rtmap-add"
 
+    # TODO: need to handle case where list is the same but 'additive'
+    # is only addition or removal
     def update(self, old, upd, new, rtmap, seq):
         l = self.enter(rtmap, new, seq)
-        for cmty in self.get_ext(upd):
-            l.append(" set community " + cmty)
+        for cmty in sorted(self.get_ext(upd)):
+            l.append(" set community "
+                     + cmty
+                     + (" additive" if "additive" in new["set"]["community"]
+                            else ""))
         return l
 
 
@@ -332,7 +337,7 @@ class Cvt_RtMap_SetIPNxtHopVrfy(DiffConvert_RtMap_Entry):
     ext = "set", "ip-next-hop-verify-availability"
 
     def remove(self, old, rtmap, seq):
-        l = self.enter(rtmap, new, seq)
+        l = self.enter(rtmap, old, seq)
         l.append(" no set ip next-hop verify-availability")
         return l
 
@@ -343,7 +348,7 @@ class Cvt_RtMap_SetIPNxtHopVrfy(DiffConvert_RtMap_Entry):
 
 class Cvt_RtMap_SetIPNxtHopVrfyTrk(DiffConvert_RtMap_Entry):
     cmd = tuple()
-    ext = "set", "ip-next-hop-verify-availability", None
+    ext = "set", "ip-next-hop-verify-availability-track", None
 
     def _cmd(self, seq, nexthop):
         return ("set ip next-hop verify-availability %s %s track %d"
@@ -406,52 +411,6 @@ class Cvt_RtMap_SetIPv6NxtHop_Add(Cvt_RtMap_SetIPv6NxtHop):
         return l
 
 
-class Cvt_RtMap_SetIPv6NxtHopVrfy(DiffConvert_RtMap_Entry):
-    cmd = tuple()
-    ext = "set", "ipv6-next-hop-verify-availability"
-
-    def remove(self, old, rtmap, seq):
-        l = self.enter(rtmap, new, seq)
-        l.append(" no set ipv6 next-hop verify-availability")
-        return l
-
-    def update(self, old, upd, new, rtmap, seq):
-        l = self.enter(rtmap, new, seq)
-        l.append(" set ipv6 next-hop verify-availability")
-        return l
-
-
-class Cvt_RtMap_SetIPNxtHopVrfyTrk(DiffConvert_RtMap_Entry):
-    cmd = tuple()
-    ext = "set", "ipv6-next-hop-verify-availability", None
-
-    def _cmd(self, seq, nexthop):
-        return ("set ipv6 next-hop verify-availability %s %s track %d"
-                     % (nexthop["addr"], seq, nexthop["track-obj"]))
-
-class Cvt_RtMap_SetIPv6NxtHopVrfyTrk_Del(Cvt_RtMap_SetIPNxtHopVrfyTrk):
-    block = "rtmap-del"
-
-    def remove(self, old, rtmap, seq, nexthop_seq):
-        return self.enter(rtmap, old, seq) + [
-                   " no "
-                       + self._cmd(nexthop_seq,
-                                   self.get_ext(old, nexthop_seq))]
-
-class Cvt_RtMap_SetIPv6NxtHopVrfyTrk_Add(Cvt_RtMap_SetIPNxtHopVrfyTrk):
-    block = "rtmap-add"
-
-    def update(self, old, upd, new, rtmap, seq, nexthop_seq):
-        # individual entries (ordered by sequence number) can be replaced but
-        # the old entry must be removed first, before the new one added
-        l = self.enter(rtmap, new, seq)
-        if old:
-            l.append(" no "
-                     + self._cmd(nexthop_seq, self.get_ext(old, nexthop_seq)))
-        l.append(" " + self._cmd(nexthop_seq, self.get_ext(new, nexthop_seq)))
-        return l
-
-
 class Cvt_RtMap_SetLocalPref(DiffConvert_RtMap_Entry):
     cmd = tuple()
     ext = "set", "local-preference"
@@ -490,8 +449,13 @@ class Cvt_RtMap_SetVRF_Add(Cvt_RtMap_SetVRF):
 
     def update(self, old, upd, new, rtmap, seq):
         l = self.enter(rtmap, new, seq)
-        if old:
+
+        # if there's a previous setting, and we're changing from global
+        # to a VRF, or vice-versa, we need to clear the old setting
+        # first
+        if old and (bool(self.get_ext(old)) != bool(self.get_ext(new))):
             l.append(" no " + self._cmd(old))
+
         l.append(" " + self._cmd(new))
         return l
 
@@ -534,6 +498,11 @@ class Cvt_RtrOSPF_AreaNSSA(DiffConvert_RtrOSPF):
     def remove(self, old, proc, area):
         return self.enter(proc) + [" no area %s nssa" % area]
 
+    def truncate(self, old, upd, new, proc, area):
+        # if we're truncating, we're removing options and we do that by
+        # just re-entering the command without them, same as update()
+        return self.update(old, None, new, proc, area)
+
     def update(self, old, upd, new, proc, area):
         s = ""
         if "no-redistribution" in new: s += " no-redistribution"
@@ -626,6 +595,11 @@ class Cvt_RtrOSPFv3_AreaNSSA(DiffConvert_RtrOSPFv3):
     def remove(self, old, proc, area):
         return self.enter(proc) + [" no area %s nssa" % area]
 
+    def truncate(self, old, upd, new, proc, area):
+        # if we're truncating, we're removing options and we do that by
+        # just re-entering the command without them, same as update()
+        return self.update(old, None, new, proc, area)
+
     def update(self, old, upd, new, proc, area):
         s = ""
         if "no-redistribution" in new: s += " no-redistribution"
