@@ -92,7 +92,9 @@ class CiscoIOSDiffConfig(DiffConfig):
             try:
                 self._add_converter(cvt_class())
             except:
-                print("with: cvt_class=" + repr(cvt_class),
+                print("Exception in _add_converter(%s()) with:"
+                          % cvt_class.__name__,
+                      "",
                       file=sys.stderr)
 
                 raise
