@@ -16,7 +16,7 @@ class TestAsimtote_CiscoIOS_Config_Interface(unittest.TestCase):
         self.cfg = CiscoIOSConfig()
 
 
-    def test_Int_Lo(self):
+    def test_Int_lo(self):
         self.cfg.parse_str("""
 interface Loopback100
 """)
@@ -31,7 +31,7 @@ interface Loopback100
         })
 
 
-    def test_Int_Eth(self):
+    def test_Int_eth(self):
         self.cfg.parse_str("""
 interface Ethernet1/10
 """)
@@ -47,6 +47,34 @@ interface Ethernet1/10
         })
 
 
+    def test_Int_eth_sub(self):
+        self.cfg.parse_str("""
+interface Ethernet1/10.100
+""")
+
+        self.assertEqual(self.cfg, {
+            "interface": {
+                "Eth1/10.100": {
+                    "shutdown": False
+                }
+            }
+        })
+
+
+    def test_Int_vlan(self):
+        self.cfg.parse_str("""
+interface Vlan100
+""")
+
+        self.assertEqual(self.cfg, {
+            "interface": {
+                "Vl100": {
+                    "shutdown": False
+                }
+            }
+        })
+
+
     def test_Int_ARPTime(self):
         self.cfg.parse_str("""
 interface Ethernet1/10
@@ -143,7 +171,7 @@ interface Eth1/10
         })
 
 
-    def test_Int_Encap_Ntv(self):
+    def test_Int_Encap_ntv(self):
         self.cfg.parse_str("""
 interface Eth1/10
  encapsulation dot1q 100 native
@@ -159,7 +187,7 @@ interface Eth1/10
         })
 
 
-    def test_Int_Encap_Tag(self):
+    def test_Int_Encap_tag(self):
         self.cfg.parse_str("""
 interface Eth1/10
  encapsulation dot1q 100
