@@ -16,7 +16,30 @@ class TestAsimtote_CiscoIOS_Config_Router(unittest.TestCase):
         self.cfg = CiscoIOSConfig()
 
 
-    def test_IPRoute_NoInt(self):
+    # -------------------------------------------------------------------------
+    # ip[v6] route ...
+    # -------------------------------------------------------------------------
+
+
+    def test_IPRoute_int(self):
+        self.cfg.parse_str("""
+ip route 10.1.0.0 255.255.255.0 Eth1/1.100
+""")
+
+        self.assertEqual(self.cfg, {
+            "ip-route": {
+                None: {
+                    "10.1.0.0/24": {
+                        "Eth1/1.100 -": {
+                            "interface": "Eth1/1.100"
+                        }
+                    }
+                }
+            }
+        })
+
+
+    def test_IPRoute_ip(self):
         self.cfg.parse_str("""
 ip route 10.1.0.0 255.255.255.0 10.2.0.1
 """)
@@ -26,7 +49,6 @@ ip route 10.1.0.0 255.255.255.0 10.2.0.1
                 None: {
                     "10.1.0.0/24": {
                         "- 10.2.0.1": {
-                            "interface": None,
                             "router": "10.2.0.1"
                         }
                     }
@@ -35,7 +57,7 @@ ip route 10.1.0.0 255.255.255.0 10.2.0.1
         })
 
 
-    def test_IPRoute_Int(self):
+    def test_IPRoute_int_ip(self):
         self.cfg.parse_str("""
 ip route 10.1.0.0 255.255.255.0 Vlan100 10.2.0.1
 """)
@@ -54,7 +76,7 @@ ip route 10.1.0.0 255.255.255.0 Vlan100 10.2.0.1
         })
 
 
-    def test_IPRoute_VRFTag(self):
+    def test_IPRoute_vrf_tag(self):
         self.cfg.parse_str("""
 ip route vrf TestVRF 10.1.0.0 255.255.255.0 Vlan100 10.2.0.1 tag 100 20
 """)
@@ -75,7 +97,25 @@ ip route vrf TestVRF 10.1.0.0 255.255.255.0 Vlan100 10.2.0.1 tag 100 20
         })
 
 
-    def test_IPv6Route_NoInt(self):
+    def test_IPv6Route_int(self):
+        self.cfg.parse_str("""
+ipv6 route 10::1/64 Eth1/1.100
+""")
+
+        self.assertEqual(self.cfg, {
+            "ipv6-route": {
+                None: {
+                    "10::1/64": {
+                        "Eth1/1.100 -": {
+                            "interface": "Eth1/1.100"
+                        }
+                    }
+                }
+            }
+        })
+
+
+    def test_IPv6Route_ip(self):
         self.cfg.parse_str("""
 ipv6 route 10::1/64 20::1
 """)
@@ -85,7 +125,6 @@ ipv6 route 10::1/64 20::1
                 None: {
                     "10::1/64": {
                         "- 20::1": {
-                            "interface": None,
                             "router": "20::1"
                         }
                     }
@@ -94,7 +133,7 @@ ipv6 route 10::1/64 20::1
         })
 
 
-    def test_IPv6Route_Int(self):
+    def test_IPv6Route_int_ip(self):
         self.cfg.parse_str("""
 ipv6 route 10::1/64 Vlan100 20::1
 """)
@@ -113,7 +152,7 @@ ipv6 route 10::1/64 Vlan100 20::1
         })
 
 
-    def test_IPv6Route_VRFTag(self):
+    def test_IPv6Route_vrf_tag(self):
         self.cfg.parse_str("""
 ipv6 route vrf TestVRF 10::1/64 Vlan100 20::1 tag 100 20
 """)
@@ -425,34 +464,6 @@ route-map TestRtMap permit 10
         })
 
 
-    def test_RtMap_SetIPNxtHopVrfyTrk(self):
-        # check multiple next hops are supported and stored against sequence
-        # number
-        self.cfg.parse_str("""
-route-map TestRtMap permit 10
- set ipv6 next-hop verify-availability 10::1 200 track 20
- set ipv6 next-hop verify-availability 20::1 100 track 30
- set ipv6 next-hop verify-availability 30::1 300 track 10
-""")
-
-        self.assertEqual(self.cfg, {
-            "route-map": {
-                "TestRtMap": {
-                    10: {
-                        "action": "permit",
-                        "set": {
-                            "ipv6-next-hop-verify-availability-track": {
-                                100: { "addr": "20::1", "track-obj": 30 },
-                                200: { "addr": "10::1", "track-obj": 20 },
-                                300: { "addr": "30::1", "track-obj": 10 }
-                            }
-                        }
-                    }
-                }
-            }
-        })
-
-
     def test_RtMap_SetLocalPref(self):
         self.cfg.parse_str("""
 route-map TestRtMap permit 10
