@@ -172,6 +172,9 @@ interface Eth1/1
     # interface ...
     #  ip address ...
     #  ipv6 address ...
+    #  ipv6 nd prefix ...
+    #  standby ... ip ... [secondary]
+    #  standby ... ipv6 ...
     #  vrf forwarding ...
     # =========================================================================
 
@@ -184,6 +187,10 @@ interface Eth1/1
 interface Eth1/1
  ip address 10.0.0.1 255.255.255.0
  ipv6 address 10::1/64
+ ipv6 nd prefix 100::/64 at 1 feb 2020 12:00 2 mar 2020 10:00
+ standby 10 ip 10.0.0.11
+ standby 10 ip 10.0.0.12 secondary
+ standby 20 ipv6 10::11/64
 """)
 
         self.new_cfg.parse_str("""
@@ -191,6 +198,10 @@ interface Eth1/1
  vrf forwarding TestVRF
  ip address 10.0.0.1 255.255.255.0
  ipv6 address 10::1/64
+ ipv6 nd prefix 100::/64 at 1 feb 2020 12:00 2 mar 2020 10:00
+ standby 10 ip 10.0.0.11
+ standby 10 ip 10.0.0.12 secondary
+ standby 20 ipv6 10::11/64
 """)
 
         self.compare("""
@@ -202,6 +213,18 @@ interface Eth1/1
 !
 interface Eth1/1
  ipv6 address 10::1/64
+!
+interface Eth1/1
+ ipv6 nd prefix 100::/64 at 1 feb 2020 12:00 2 mar 2020 10:00
+!
+interface Eth1/1
+ standby 10 ip 10.0.0.11
+!
+interface Eth1/1
+ standby 10 ip 10.0.0.12 secondary
+!
+interface Eth1/1
+ standby 20 ipv6 10::11/64
 """)
 
 
@@ -214,12 +237,20 @@ interface Eth1/1
  vrf forwarding TestVRF
  ip address 10.0.0.1 255.255.255.0
  ipv6 address 10::1/64
+ ipv6 nd prefix 100::/64 at 1 feb 2020 12:00 2 mar 2020 10:00
+ standby 10 ip 10.0.0.11
+ standby 10 ip 10.0.0.12 secondary
+ standby 20 ipv6 10::11/64
 """)
 
         self.new_cfg.parse_str("""
 interface Eth1/1
  ip address 10.0.0.1 255.255.255.0
  ipv6 address 10::1/64
+ ipv6 nd prefix 100::/64 at 1 feb 2020 12:00 2 mar 2020 10:00
+ standby 10 ip 10.0.0.11
+ standby 10 ip 10.0.0.12 secondary
+ standby 20 ipv6 10::11/64
 """)
 
         self.compare("""
@@ -231,6 +262,18 @@ interface Eth1/1
 !
 interface Eth1/1
  ipv6 address 10::1/64
+
+interface Eth1/1
+ ipv6 nd prefix 100::/64 at 1 feb 2020 12:00 2 mar 2020 10:00
+!
+interface Eth1/1
+ standby 10 ip 10.0.0.11
+!
+interface Eth1/1
+ standby 10 ip 10.0.0.12 secondary
+!
+interface Eth1/1
+ standby 20 ipv6 10::11/64
 """)
 
 
@@ -243,6 +286,10 @@ interface Eth1/1
  vrf forwarding TestVRF1
  ip address 10.0.0.1 255.255.255.0
  ipv6 address 10::1/64
+ ipv6 nd prefix 100::/64 at 1 feb 2020 12:00 2 mar 2020 10:00
+ standby 10 ip 10.0.0.11
+ standby 10 ip 10.0.0.12 secondary
+ standby 20 ipv6 10::11/64
 """)
 
         self.new_cfg.parse_str("""
@@ -250,6 +297,10 @@ interface Eth1/1
  vrf forwarding TestVRF2
  ip address 10.0.0.1 255.255.255.0
  ipv6 address 10::1/64
+ ipv6 nd prefix 100::/64 at 1 feb 2020 12:00 2 mar 2020 10:00
+ standby 10 ip 10.0.0.11
+ standby 10 ip 10.0.0.12 secondary
+ standby 20 ipv6 10::11/64
 """)
 
         self.compare("""
@@ -261,6 +312,18 @@ interface Eth1/1
 !
 interface Eth1/1
  ipv6 address 10::1/64
+
+interface Eth1/1
+ ipv6 nd prefix 100::/64 at 1 feb 2020 12:00 2 mar 2020 10:00
+!
+interface Eth1/1
+ standby 10 ip 10.0.0.11
+!
+interface Eth1/1
+ standby 10 ip 10.0.0.12 secondary
+!
+interface Eth1/1
+ standby 20 ipv6 10::11/64
 """)
 
 
@@ -3477,7 +3540,9 @@ interface Eth1/1
     # -------------------------------------------------------------------------
 
 
-    def test_Interface_StandbyIP_update(self):
+    def test_Interface_StandbyIPSec_update(self):
+        # change a secondary address
+
         self.old_cfg.parse_str("""
 interface Eth1/1
  standby 81 ip 10.0.0.1
@@ -3499,6 +3564,102 @@ interface Eth1/1
 """)
 
 
+    # =========================================================================
+    # interface ...
+    #  standby ... ip ...
+    #  standby ... ip ... secondary
+    # =========================================================================
+
+
+    def test_Interface_StandbyIPandSec_update_promote(self):
+        # promote a secondary address to primary
+        #
+        # this requires that the secondary is removed first
+
+        self.old_cfg.parse_str("""
+interface Eth1/1
+ standby 81 ip 10.0.0.1
+ standby 81 ip 20.0.0.1 secondary
+""")
+
+        self.new_cfg.parse_str("""
+interface Eth1/1
+ standby 81 ip 20.0.0.1
+""")
+
+        self.compare("""
+interface Eth1/1
+ no standby 81 ip 20.0.0.1 secondary
+!
+interface Eth1/1
+ standby 81 ip 20.0.0.1
+""")
+
+
+    # -------------------------------------------------------------------------
+
+
+    def test_Interface_StandbyIPandSec_update_demote(self):
+        # demote the primary address to a secondary (adding a new
+        # primary, but this is not checked for)
+        #
+        # this requires that the new primary is installed first and then
+        # the old one added as a secondary
+
+        self.old_cfg.parse_str("""
+interface Eth1/1
+ standby 81 ip 10.0.0.1
+""")
+
+        self.new_cfg.parse_str("""
+interface Eth1/1
+ standby 81 ip 20.0.0.1
+ standby 81 ip 10.0.0.1 secondary
+""")
+
+        self.compare("""
+interface Eth1/1
+ standby 81 ip 20.0.0.1
+!
+interface Eth1/1
+ standby 81 ip 10.0.0.1 secondary
+""")
+
+
+    # -------------------------------------------------------------------------
+
+
+    def test_Interface_StandbyIPandSec_update_swap(self):
+        # swap the primary and a secondary address
+        #
+        # this requires that the old secondary is removed first, then
+        # the primary changed and then the old primary configured as the
+        # secondary
+
+        self.old_cfg.parse_str("""
+interface Eth1/1
+ standby 81 ip 10.0.0.1
+ standby 81 ip 20.0.0.1 secondary
+""")
+
+        self.new_cfg.parse_str("""
+interface Eth1/1
+ standby 81 ip 20.0.0.1
+ standby 81 ip 10.0.0.1 secondary
+""")
+
+        self.compare("""
+interface Eth1/1
+ no standby 81 ip 20.0.0.1 secondary
+!
+interface Eth1/1
+ standby 81 ip 20.0.0.1
+!
+interface Eth1/1
+ standby 81 ip 10.0.0.1 secondary
+""")
+
+
     # =========================================================================
     # interface ...
     #  standby ... ipv6 ...
